==> eiffelstudio-18.11.10.2592.tar: F_code/C6/kl298.c <==
/*
 * Code for class KL_IMPORTED_SPECIAL_ROUTINES
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "kl298.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {KL_IMPORTED_SPECIAL_ROUTINES}.special_boolean_ */
static EIF_REFERENCE F438_3443_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOSP (3443);
#define Result RTOSR(3443)
	RTOC_NEW(Result);
	{
		static EIF_TYPE_INDEX typarr0[] = {36,1039,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 36, _OBJSIZ_0_0_0_0_0_0_0_0_);
	}
	Result = (EIF_REFERENCE) tr1;
	RTOSE (3443);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F438_3443 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(3443,F438_3443_body,(Current));
}

/* {KL_IMPORTED_SPECIAL_ROUTINES}.special_integer_ */
static EIF_REFERENCE F438_3445_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOSP (3445);
#define Result RTOSR(3445)
	RTOC_NEW(Result);
	{
		static EIF_TYPE_INDEX typarr0[] = {35,1006,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 35, _OBJSIZ_0_0_0_0_0_0_0_0_);
	}
	Result = (EIF_REFERENCE) tr1;
	RTOSE (3445);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F438_3445 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(3445,F438_3445_body,(Current));
}

void EIF_Minit298 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-23.09.10.7341.tar: F_code/C6/kl298.c <==
/*
 * Code for class KL_IMPORTED_SPECIAL_ROUTINES
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "kl298.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {KL_IMPORTED_SPECIAL_ROUTINES}.special_integer_ */
static EIF_REFERENCE F379_3219_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOSP (3219);
#define Result RTOSR(3219)
	RTOC_NEW(Result);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,45,1036,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 45, _OBJSIZ_0_0_0_0_0_0_0_0_);
	}
	Result = (EIF_REFERENCE) tr1;
	RTOSE (3219);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F379_3219 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(3219,F379_3219_body,(Current));
}

/* {KL_IMPORTED_SPECIAL_ROUTINES}.special_natural_32_ */
static EIF_REFERENCE F379_3220_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEV;
	RTGC;
	RTOSP (3220);
#define Result RTOSR(3220)
	RTOC_NEW(Result);
	{
		static EIF_TYPE_INDEX typarr0[] = {0xFF01,50,1048,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 50, _OBJSIZ_0_0_0_0_0_0_0_0_);
	}
	Result = (EIF_REFERENCE) tr1;
	RTOSE (3220);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F379_3220 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(3220,F379_3220_body,(Current));
}

void EIF_Minit298 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
